@@ -19,7 +19,7 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         if not len(args):
-            print "You must provide the feed url as parameter"
+            print("You must provide the feed url as parameter")
             exit(0)
 
         feed_url = args[0]
